@@ -9,7 +9,6 @@ import sys
 import json
 import re
 
-
 defaultInput={"password for*": "intel123",
             "Password*":"intel123",
             "Do you want to continue?": "Y"}
@@ -23,7 +22,7 @@ def execute_process(process_string, serviceName, version=None):
     ret_status = True
     try:
         if process_string != "":
-            cmd = "/bin/bash -c 'ls'"
+            #cmd = "/bin/bash -c 'ls'"
             cmd = "/bin/bash -c '{0}.sh {1}'".format(process_string,serviceName)
             #cmd = "/bin/bash -c '{0} {1}'".format(process_string,serviceName)
         else:
@@ -63,7 +62,7 @@ def expect_wrapper(cmd, input_dict=defaultInput):
             i = child.expect(temp)
             #print_msg("Input expect {0} ".format(i))
             if i != len(temp)-1:
-                child.setecho(True)
+                child.setecho(False)
                 child.sendline((list(input_dict.values())[i]))
             else:
                 break
@@ -77,11 +76,11 @@ def expect_wrapper(cmd, input_dict=defaultInput):
             # data=ansi_escape_8bit.sub(b'', data)
             # data=data.replace(b'\r',b'')
             #data=data.decode("latin-1")
-            #print("Command line output for: {0} {1}".format(cmd,data))
+            #print("Command line output for: {0}".format(cmd))
         except BaseException as error:
             print('An exception occurred while decoding CLI output: {}'.format(error))
         finally:
-            return (child.before, child.status, child.exitstatus)
+            return (child.status, child.exitstatus)
     except BaseException as error:
         print('An exception occurred in wrapper: {}'.format(error))
         raise
